// storage-adapter-import-placeholder
import { postgresAdapter } from "@payloadcms/db-postgres";
import { payloadCloudPlugin } from "@payloadcms/payload-cloud";
import { lexicalEditor } from "@payloadcms/richtext-lexical";
import path from "path";
import { buildConfig } from "payload";
import { fileURLToPath } from "url";
import sharp from "sharp";

import { s3Storage } from "@payloadcms/storage-s3";
import { Users } from "@/collections/Users";
import { Media } from "@/collections/Media";
import { BlogTags } from "@/collections/BlogTags";
import { BlogCategories } from "@/collections/BlogCategories";
import { Blogs } from "@/collections/Blogs";
import { PropertyFeatures } from "@/collections/PropertyFeatures";
import { Properties } from "./collections/Properties";
import { Pages } from "@/collections/Pages";
import { formBuilderPlugin } from "@payloadcms/plugin-form-builder";

const filename = fileURLToPath(import.meta.url);
const dirname = path.dirname(filename);

export default buildConfig({
  admin: {
    user: Users.slug,
    importMap: {
      baseDir: path.resolve(dirname),
    },
    meta: {
      titleSuffix: "- Admin - Dynamic Realty",
      description: "Dynamic Realty",
      icons: [{ url: "/images/logo2.png" }],
    },
    components: {
      graphics: {
        Logo: {
          path: "/components/LogoAdmin",
        },
      },
    },
    theme: "dark",
  },
  collections: [Users, Media, BlogTags, BlogCategories, Blogs, PropertyFeatures, Properties, Pages],
  editor: lexicalEditor(),
  secret: process.env.PAYLOAD_SECRET || "",
  typescript: {
    outputFile: path.resolve(dirname, "payload-types.ts"),
  },
  db: postgresAdapter({
    pool: {
      connectionString: process.env.DATABASE_URI || "",
    },
  }),
  sharp,
  plugins: [
    payloadCloudPlugin(),
    // storage-adapter-placeholder,
    s3Storage({
      collections: {
        media: {
          prefix: "media",
        },
      },
      bucket: process.env.S3_BUCKET || "",
      config: {
        forcePathStyle: true, // Important for using Supabase
        credentials: {
          accessKeyId: process.env.S3_ACCESS_KEY_ID || "",
          secretAccessKey: process.env.S3_SECRET_ACCESS_KEY || "",
        },
        region: process.env.S3_REGION,
        endpoint: process.env.S3_ENDPOINT,
      },
    }),
    // form builder
    formBuilderPlugin({
      fields: {
        checkbox: true,
        email: true,
        number: true,
        select: true,
        text: true,
        textarea: true,
        country: false,
        state: false,
        payment: false,
      },
      formOverrides: {
        fields: undefined,
        admin: {
          group: "General",
          useAsTitle: "title",
        },
      },
      formSubmissionOverrides: {
        fields: undefined,
        admin: {
          group: "General",
          useAsTitle: "form",
        },
      },
      // beforeEmail: (emailsToSend, beforeChangeParams) => {
      //   if (beforeChangeParams.data.form === 1) {
      //     const submissionData: Record<string, any> = {};
      //     for (const s of beforeChangeParams.data.submissionData) {
      //       submissionData[s.field] = s.value;
      //     }

      //     submissionData["confirmation"] = submissionData["confirmation"]
      //       ? "I consent to receive text messages and emails, and that I am 18+ years old."
      //       : "";

      //     // modify the emails in any way before they are sent
      //     return emailsToSend.map((email) => {
      //       return {
      //         ...email,
      //         html: loadEmailTemplate("contact-form-email.html", submissionData),
      //       };
      //     });
      //   }

      //   return emailsToSend;
      // },
    }),
  ],
});
